# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/regex.proto',
  package='rockset',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13rockset/regex.proto\x12\x07rockset\"e\n\x05Regex\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12)\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x17.rockset.Regex.Encoding\" \n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\n\n\x06LATIN1\x10\x01\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3'
)



_REGEX_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='rockset.Regex.Encoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UTF8', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LATIN1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=101,
  serialized_end=133,
)
_sym_db.RegisterEnumDescriptor(_REGEX_ENCODING)


_REGEX = _descriptor.Descriptor(
  name='Regex',
  full_name='rockset.Regex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern', full_name='rockset.Regex.pattern', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='rockset.Regex.encoding', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REGEX_ENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=133,
)

_REGEX.fields_by_name['encoding'].enum_type = _REGEX_ENCODING
_REGEX_ENCODING.containing_type = _REGEX
DESCRIPTOR.message_types_by_name['Regex'] = _REGEX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Regex = _reflection.GeneratedProtocolMessageType('Regex', (_message.Message,), {
  'DESCRIPTOR' : _REGEX,
  '__module__' : 'rockset.regex_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Regex)
  })
_sym_db.RegisterMessage(Regex)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from .command_auth import AuthCommand
from rockset.query import QueryStringSQLText
import sys
import time


class SQLQuery(AuthCommand):
    def usage(self):
        return """
usage: rock sql --help
       rock sql
       rock sql <sql_statement> [<args>...]

Run a sql query and return results as documents.

arguments:
  <sql-statement>       sql query to run; will read from STDIN if == '-'

examples:

  # To enter into the rock SQL REPL
  $ rock sql

  # To run a simple SQL query
  $ rock sql 'SELECT * from my_collection LIMIT 10'

  # To supply SQL from STDIN, use "-"
  $ echo 'SELECT * from my_collection LIMIT 10' | rock sql -

        """

    def validate_args(self, pargs):
        allowed_args = ['drop_results']
        for arg in pargs['<args>']:
            if arg not in allowed_args:
                return False
        return True

    def go(self):
        if not self.sql_statement:
            try:
                from rockset_sqlcli.rscli.main import cli_main
            except (ImportError, FileNotFoundError) as e:
                raise ImportError(
                    'Python package rockset_sqlcli is not installed. '
                    'Please run `pip3 install rockset_sqlcli` and try again!'
                )
            return cli_main(
                api_server=self.api_server,
                api_key=self.api_key,
                workspace='commons',
                generate_warnings=self.warn,
            )
        elif self.sql_statement == '-':
            self.sql_statement = self.read_stdin('SQL query')
        q = QueryStringSQLText(self.sql_statement)

        # lets do this
        start = time.time()
        cursor = self.client.sql(q=q, generate_warnings=self.warn)

        results = cursor.results()
        warnings = cursor.warnings()
        fields = cursor.fields() or []
        elapsed = round(1000 * (time.time() - start))
        if self.warn and warnings is not None:
            self.wprint(warnings)
        if 'drop_results' in self.args:
            print(
                'Query returned {} rows in {}ms'.format(len(results), elapsed)
            )
        else:
            self.print_list(0, results, field_order=[f['name'] for f in fields])

        return 0



from rockset.swagger_client.api import IntegrationsApi
from rockset.swagger_client.models import (
    AwsAccessKey,
    AwsRole,
    CreateIntegrationRequest,
    DynamodbIntegration,
    MongoDbIntegration,
    KinesisIntegration,
    GcpServiceAccount,
    GcsIntegration,
    RedshiftIntegration,
    S3Integration,
    KafkaIntegration,
)


class IntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

        self.Dynamodb = DynamodbIntegrationClient(client)
        self.MongoDb = MongoDbIntegrationClient(client)
        self.Gcs = GcsIntegrationClient(client)
        self.Kinesis = KinesisIntegrationClient(client)
        self.Redshift = RedshiftIntegrationClient(client)
        self.S3 = S3IntegrationClient(client)
        self.Kafka = KafkaIntegrationClient(client)

    def list(self):
        return self.api.list().get('data')

    def get(self, name=None, **kwargs):
        return self.api.get(name).get('data')

    def delete(self, name=None, **kwargs):
        return self.api.delete(name).get('data')

    def retrieve(self, name=None, **kwargs):
        return self.get(name)

    def drop(self, name=None, **kwargs):
        return self.delete(name)


class DynamodbIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        aws_access_key_id=None,
        aws_secret_access_key=None,
        **kwargs
    ):

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            dynamodb=DynamodbIntegration(
                aws_access_key=AwsAccessKey(
                    aws_access_key_id=aws_access_key_id,
                    aws_secret_access_key=aws_secret_access_key,
                ),
            ),
        )

        return self.api.create(body=request).get('data')


class MongoDbIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self, name=None, description=None, connection_uri=None, **kwargs
    ):
        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            mongodb=MongoDbIntegration(connection_uri=connection_uri),
        )

        return self.api.create(body=request).get('data')


class GcsIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        service_account_key_file_json=None,
        **kwargs
    ):

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            gcs=GcsIntegration(
                gcp_service_account=GcpServiceAccount(
                    service_account_key_file_json=service_account_key_file_json,
                ),
            ),
        )

        return self.api.create(body=request).get('data')


class KinesisIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        aws_access_key_id=None,
        aws_secret_access_key=None,
        aws_role_arn=None,
        **kwargs
    ):
        if aws_role_arn:
            kinesis = KinesisIntegration(
                aws_role=AwsRole(aws_role_arn=aws_role_arn),
            )
        elif aws_access_key_id or aws_secret_access_key:
            kinesis = KinesisIntegration(
                aws_access_key=AwsAccessKey(
                    aws_access_key_id=aws_access_key_id,
                    aws_secret_access_key=aws_secret_access_key,
                ),
            )
        else:
            kinesis = None

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            kinesis=kinesis,
        )

        return self.api.create(body=request).get('data')


class RedshiftIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        aws_access_key_id=None,
        aws_secret_access_key=None,
        username=None,
        password=None,
        host=None,
        port=None,
        s3_bucket_path=None,
        **kwargs
    ):

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            redshift=RedshiftIntegration(
                aws_access_key=AwsAccessKey(
                    aws_access_key_id=aws_access_key_id,
                    aws_secret_access_key=aws_secret_access_key,
                ),
                username=username,
                password=password,
                host=host,
                port=port,
                s3_bucket_path=s3_bucket_path,
            ),
        )

        return self.api.create(body=request).get('data')


class S3IntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        aws_access_key_id=None,
        aws_secret_access_key=None,
        aws_role_arn=None,
        **kwargs
    ):
        if aws_role_arn:
            s3 = S3Integration(aws_role=AwsRole(aws_role_arn=aws_role_arn))
        elif aws_access_key_id or aws_secret_access_key:
            s3 = S3Integration(
                aws_access_key=AwsAccessKey(
                    aws_access_key_id=aws_access_key_id,
                    aws_secret_access_key=aws_secret_access_key,
                ),
            )
        else:
            s3 = None

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            s3=s3,
        )

        return self.api.create(body=request).get('data')


class KafkaIntegrationClient(object):
    def __init__(self, client):
        self.api = IntegrationsApi(client)

    def create(
        self,
        name=None,
        description=None,
        kafka_topic_names=None,
        kafka_data_format=None,
        **kwargs
    ):

        request = CreateIntegrationRequest(
            name=name,
            description=(description if description else ''),
            kafka=KafkaIntegration(
                kafka_topic_names=kafka_topic_names,
                kafka_data_format=kafka_data_format,
            ),
        )

        return self.api.create(body=request).get('data')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/document_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rockset/document_locator.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\020io.rockset.protoP\000\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1erockset/document_locator.proto\"J\n\x14\x44ocumentLocatorProto\x12\x0e\n\x06raw_id\x18\x01 \x01(\x04\x12\x0f\n\x07indices\x18\x02 \x03(\r\x12\x11\n\tpartition\x18\x03 \x01(\x03\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3'
)




_DOCUMENTLOCATORPROTO = _descriptor.Descriptor(
  name='DocumentLocatorProto',
  full_name='DocumentLocatorProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_id', full_name='DocumentLocatorProto.raw_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indices', full_name='DocumentLocatorProto.indices', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition', full_name='DocumentLocatorProto.partition', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=108,
)

DESCRIPTOR.message_types_by_name['DocumentLocatorProto'] = _DOCUMENTLOCATORPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DocumentLocatorProto = _reflection.GeneratedProtocolMessageType('DocumentLocatorProto', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTLOCATORPROTO,
  '__module__' : 'rockset.document_locator_pb2'
  # @@protoc_insertion_point(class_scope:DocumentLocatorProto)
  })
_sym_db.RegisterMessage(DocumentLocatorProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



"""
Introduction
------------

FieldMapping objects allow you to specify transformations to be applied on all documents inserted
into a collection. Any valid SQL can be applied on any field in a document.

For more information on field mappings, refer to `the official documentation <https://docs.rockset.com/field-mappings/>`_.

Example of basic field mapping
------------------------------
::

    from rockset import Client

    rs = Client()

    mappings = [
        rs.FieldMapping.mapping(
            name="anonymize_name",
            input_fields=[
                rs.FieldMapping.input_field(
                    field_name="name",
                    if_missing="SKIP",
                    is_drop=True,
                    param="name"
                )
            ],
            output_field=rs.FieldMapping.output_field(
                field_name="name", sql_expression="SHA256(:name)", on_error="FAIL"
            )
        )
    ]

    # This collection will have all its `name` fields anonymized through the SQL expression
    # in the output field above.
    collection = rs.Collection.create(name="collection", field_mappings=mappings)

Example of field whitelisting
-----------------------------
::

    from rockset import Client

    rs = Client()

    mappings = [
        rs.FieldMapping.mapping(name="drop_all_fields", is_drop_all_fields=True),
        rs.FieldMapping.mapping(
            name="whitelist_name",
            input_fields=[
                rs.FieldMapping.input_field(
                    field_name="name",
                    if_missing="SKIP",
                    is_drop=True,
                    param="name"
                )
            ],
            output_field=rs.FieldMapping.output_field(
                field_name="name", sql_expression=":name", on_error="FAIL"
            )
        )
    ]

    # This collection will have `name` as a whitelisted field, essentially dropping all fields
    # except for `name`.
    collection = rs.Collection.create(name="collection", field_mappings=mappings)

"""


class FieldMapping(object):
    def __str__(self):
        return str(vars(self))

    def __iter__(self):
        for k, v in vars(self).items():
            yield (k, v)

    @classmethod
    def mapping(
        cls,
        name,
        is_drop_all_fields=None,
        input_fields=None,
        output_field=None
    ):
        """Creates a new mapping object

        Args:
            name(str): Name of the mapping
            is_drop_all_fields(bool): Whether to drop all the fields in a document. This can only be set once
                in a list of field mappings, and a mapping specifying `is_drop_all_fields` cannot have any input or output fields
            input_fields: An Array of InputField objects
            output: An OutputField object
        """
        input_dict = [dict(f) for f in input_fields] if input_fields else None
        output_dict = dict(output_field) if output_field else None

        return Mapping(
            name=name,
            is_drop_all_fields=is_drop_all_fields,
            input_fields=input_dict,
            output_field=output_dict
        )

    @classmethod
    def input_field(cls, field_name, param=None, if_missing=None, is_drop=None):
        """Create a new InputField object

        Args:
            field_name (str): The name of the field, parsed as a SQL qualified name
            param (str): SQL parameter name (default: same as field name. Required
                if the field name is nested)

                if_missing (str): Define the behavior if the field is missing from the document or is NULL,
                one of:

                    * `SKIP`: skip the SQL expression in the output field, i.e. acts as if the field mapping does not exist

                    * `PASS`: pass NULL to the SQL expression specified in the output field

                Default is `SKIP`.
            is_drop (boolean): Set to true if the input field needs to be dropped
        """
        return InputField(
            field_name=field_name,
            param=param,
            if_missing=if_missing,
            is_drop=is_drop
        )

    @classmethod
    def output_field(cls, field_name, sql_expression, on_error=None):
        """Create a new OutputField object

        Args:
            field_name (str): The name of the field, parsed as SQL qualified name
            value (Value): SQL expression
            on_error (str): Define the behavior if the SQL expression fails, one of:

                * `SKIP`: skip the SQL expression, i.e. acts as if the mapping does not exist

                * `FAIL`: fail the entire mapping, i.e. acts as if the document does not exist

                Default is `SKIP`.
        """
        return OutputField(
            field_name=field_name,
            sql_expression=sql_expression,
            on_error=on_error
        )


class Mapping(FieldMapping):
    def __init__(
        self,
        name,
        is_drop_all_fields=None,
        input_fields=None,
        output_field=None
    ):
        self.name = name
        self.is_drop_all_fields = is_drop_all_fields
        self.input_fields = input_fields

        if output_field is not None:
            self.output_field = output_field


class InputField:
    def __init__(self, field_name, param=None, if_missing=None, is_drop=None):
        self.field_name = field_name
        if param is not None:
            self.param = param
        if if_missing is not None:
            self.if_missing = if_missing
        if is_drop is not None:
            self.is_drop = is_drop
        return

    def __str__(self):
        return str(vars(self))

    def __iter__(self):
        for k, v in vars(self).items():
            yield (k, v)


class OutputField:
    def __init__(self, field_name, sql_expression, on_error=None):
        self.field_name = field_name
        self.value = {
            'sql': sql_expression,
        }
        if on_error is not None:
            self.on_error = on_error
        return

    def __str__(self):
        return str(vars(self))

    def __iter__(self):
        for k, v in vars(self).items():
            yield (k, v)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from rockset.swagger_client.api.api_keys_api import APIKeysApi
from rockset.swagger_client.api.aliases_api import AliasesApi
from rockset.swagger_client.api.collections_api import CollectionsApi
from rockset.swagger_client.api.documents_api import DocumentsApi
from rockset.swagger_client.api.ip_allowlist_api import IPAllowlistApi
from rockset.swagger_client.api.integrations_api import IntegrationsApi
from rockset.swagger_client.api.organizations_api import OrganizationsApi
from rockset.swagger_client.api.queries_api import QueriesApi
from rockset.swagger_client.api.query_lambdas_api import QueryLambdasApi
from rockset.swagger_client.api.users_api import UsersApi
from rockset.swagger_client.api.virtual_instances_api import VirtualInstancesApi
from rockset.swagger_client.api.workspaces_api import WorkspacesApi




# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.query_lambda_version import QueryLambdaVersion  # noqa: F401,E501


class QueryLambda(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workspace': 'str',
        'last_updated_by': 'str',
        'last_updated': 'str',
        'name': 'str',
        'version_count': 'int',
        'collections': 'list[str]',
        'latest_version': 'QueryLambdaVersion'
    }

    attribute_map = {
        'workspace': 'workspace',
        'last_updated_by': 'last_updated_by',
        'last_updated': 'last_updated',
        'name': 'name',
        'version_count': 'version_count',
        'collections': 'collections',
        'latest_version': 'latest_version'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """QueryLambda - a model defined in Swagger"""  # noqa: E501

        self._workspace = None
        self._last_updated_by = None
        self._last_updated = None
        self._name = None
        self._version_count = None
        self._collections = None
        self._latest_version = None
        self.discriminator = None

        self.workspace = kwargs.pop('workspace', None)
        self.last_updated_by = kwargs.pop('last_updated_by', None)
        self.last_updated = kwargs.pop('last_updated', None)
        self.name = kwargs.pop('name', None)
        self.version_count = kwargs.pop('version_count', None)
        self.collections = kwargs.pop('collections', None)
        self.latest_version = kwargs.pop('latest_version', None)

    @property
    def workspace(self):
        """Gets the workspace of this QueryLambda.  # noqa: E501

        workspace of this Query Lambda  # noqa: E501

        :return: The workspace of this QueryLambda.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this QueryLambda.

        workspace of this Query Lambda  # noqa: E501

        :param workspace: The workspace of this QueryLambda.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    @property
    def last_updated_by(self):
        """Gets the last_updated_by of this QueryLambda.  # noqa: E501

        user that created this Query Lambda  # noqa: E501

        :return: The last_updated_by of this QueryLambda.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, last_updated_by):
        """Sets the last_updated_by of this QueryLambda.

        user that created this Query Lambda  # noqa: E501

        :param last_updated_by: The last_updated_by of this QueryLambda.  # noqa: E501
        :type: str
        """

        self._last_updated_by = last_updated_by

    @property
    def last_updated(self):
        """Gets the last_updated of this QueryLambda.  # noqa: E501

        ISO-8601 date of when Query Lambda was last updated  # noqa: E501

        :return: The last_updated of this QueryLambda.  # noqa: E501
        :rtype: str
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this QueryLambda.

        ISO-8601 date of when Query Lambda was last updated  # noqa: E501

        :param last_updated: The last_updated of this QueryLambda.  # noqa: E501
        :type: str
        """

        self._last_updated = last_updated

    @property
    def name(self):
        """Gets the name of this QueryLambda.  # noqa: E501

        Query Lambda name  # noqa: E501

        :return: The name of this QueryLambda.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this QueryLambda.

        Query Lambda name  # noqa: E501

        :param name: The name of this QueryLambda.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version_count(self):
        """Gets the version_count of this QueryLambda.  # noqa: E501

        number of Query Lambda versions  # noqa: E501

        :return: The version_count of this QueryLambda.  # noqa: E501
        :rtype: int
        """
        return self._version_count

    @version_count.setter
    def version_count(self, version_count):
        """Sets the version_count of this QueryLambda.

        number of Query Lambda versions  # noqa: E501

        :param version_count: The version_count of this QueryLambda.  # noqa: E501
        :type: int
        """

        self._version_count = version_count

    @property
    def collections(self):
        """Gets the collections of this QueryLambda.  # noqa: E501

        collections/aliases queried by underlying SQL query  # noqa: E501

        :return: The collections of this QueryLambda.  # noqa: E501
        :rtype: list[str]
        """
        return self._collections

    @collections.setter
    def collections(self, collections):
        """Sets the collections of this QueryLambda.

        collections/aliases queried by underlying SQL query  # noqa: E501

        :param collections: The collections of this QueryLambda.  # noqa: E501
        :type: list[str]
        """

        self._collections = collections

    @property
    def latest_version(self):
        """Gets the latest_version of this QueryLambda.  # noqa: E501

        Query Lambda version details for most recently created version  # noqa: E501

        :return: The latest_version of this QueryLambda.  # noqa: E501
        :rtype: QueryLambdaVersion
        """
        return self._latest_version

    @latest_version.setter
    def latest_version(self, latest_version):
        """Sets the latest_version of this QueryLambda.

        Query Lambda version details for most recently created version  # noqa: E501

        :param latest_version: The latest_version of this QueryLambda.  # noqa: E501
        :type: QueryLambdaVersion
        """

        self._latest_version = latest_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryLambda, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryLambda):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.cluster import Cluster  # noqa: F401,E501


class Organization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'deletion_scheduled_at': 'str',
        'id': 'str',
        'created_at': 'str',
        'display_name': 'str',
        'company_name': 'str',
        'external_id': 'str',
        'rockset_user': 'str',
        'state': 'str',
        'clusters': 'list[Cluster]'
    }

    attribute_map = {
        'deletion_scheduled_at': 'deletionScheduledAt',
        'id': 'id',
        'created_at': 'created_at',
        'display_name': 'display_name',
        'company_name': 'company_name',
        'external_id': 'external_id',
        'rockset_user': 'rockset_user',
        'state': 'state',
        'clusters': 'clusters'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """Organization - a model defined in Swagger"""  # noqa: E501

        self._deletion_scheduled_at = None
        self._id = None
        self._created_at = None
        self._display_name = None
        self._company_name = None
        self._external_id = None
        self._rockset_user = None
        self._state = None
        self._clusters = None
        self.discriminator = None

        self.deletion_scheduled_at = kwargs.pop('deletion_scheduled_at', None)
        self.id = kwargs.pop('id', None)
        self.created_at = kwargs.pop('created_at', None)
        self.display_name = kwargs.pop('display_name', None)
        self.company_name = kwargs.pop('company_name', None)
        self.external_id = kwargs.pop('external_id', None)
        self.rockset_user = kwargs.pop('rockset_user', None)
        self.state = kwargs.pop('state', None)
        self.clusters = kwargs.pop('clusters', None)

    @property
    def deletion_scheduled_at(self):
        """Gets the deletion_scheduled_at of this Organization.  # noqa: E501


        :return: The deletion_scheduled_at of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._deletion_scheduled_at

    @deletion_scheduled_at.setter
    def deletion_scheduled_at(self, deletion_scheduled_at):
        """Sets the deletion_scheduled_at of this Organization.


        :param deletion_scheduled_at: The deletion_scheduled_at of this Organization.  # noqa: E501
        :type: str
        """

        self._deletion_scheduled_at = deletion_scheduled_at

    @property
    def id(self):
        """Gets the id of this Organization.  # noqa: E501

        unique identifier for the organization  # noqa: E501

        :return: The id of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Organization.

        unique identifier for the organization  # noqa: E501

        :param id: The id of this Organization.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Organization.  # noqa: E501

        ISO-8601 date  # noqa: E501

        :return: The created_at of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Organization.

        ISO-8601 date  # noqa: E501

        :param created_at: The created_at of this Organization.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def display_name(self):
        """Gets the display_name of this Organization.  # noqa: E501

        name of the organization  # noqa: E501

        :return: The display_name of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Organization.

        name of the organization  # noqa: E501

        :param display_name: The display_name of this Organization.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def company_name(self):
        """Gets the company_name of this Organization.  # noqa: E501

        name of the company  # noqa: E501

        :return: The company_name of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this Organization.

        name of the company  # noqa: E501

        :param company_name: The company_name of this Organization.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def external_id(self):
        """Gets the external_id of this Organization.  # noqa: E501

        organization's unique external ID within Rockset  # noqa: E501

        :return: The external_id of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Organization.

        organization's unique external ID within Rockset  # noqa: E501

        :param external_id: The external_id of this Organization.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def rockset_user(self):
        """Gets the rockset_user of this Organization.  # noqa: E501


        :return: The rockset_user of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._rockset_user

    @rockset_user.setter
    def rockset_user(self, rockset_user):
        """Sets the rockset_user of this Organization.


        :param rockset_user: The rockset_user of this Organization.  # noqa: E501
        :type: str
        """

        self._rockset_user = rockset_user

    @property
    def state(self):
        """Gets the state of this Organization.  # noqa: E501

        org state  # noqa: E501

        :return: The state of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Organization.

        org state  # noqa: E501

        :param state: The state of this Organization.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def clusters(self):
        """Gets the clusters of this Organization.  # noqa: E501


        :return: The clusters of this Organization.  # noqa: E501
        :rtype: list[Cluster]
        """
        return self._clusters

    @clusters.setter
    def clusters(self, clusters):
        """Sets the clusters of this Organization.


        :param clusters: The clusters of this Organization.  # noqa: E501
        :type: list[Cluster]
        """

        self._clusters = clusters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Organization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Organization):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



import os
import sys

from docopt import docopt
from rockset.credentials import Credentials
from .command import Command


def _format_secret(value):
    if value is None:
        return None
    i = 1
    if len(value) >= 20:
        i = 4
    return '%s**********%s' % (value[:i], value[-i:])


def _prompt_api_key(api_key=None):
    return [
        {
            'key': 'api_key',
            'message': 'Enter Rockset API key',
            'prompt': '  API Key',
            'default': {
                'display': _format_secret(api_key),
                'value': api_key,
            }
        }
    ]


def _prompt_api_server(api_server=None):
    return [
        {
            'key': 'api_server',
            'message': 'Enter Rockset API server URL',
            'prompt': '  API Server',
            'default': {
                'display': api_server,
                'value': api_server,
            }
        }
    ]


def _interactive_prompt(config):
    out = {}
    for item in config:
        key = item['key']
        message = item['message']
        prompt = item['prompt']
        default = item['default']
        if 'display' in default:
            prompt += ' [%s]' % default['display']
        sys.stdout.write(message + '\n')
        sys.stdout.write(prompt + ': ')
        sys.stdout.flush()
        value = input()
        value = value.strip()
        if value == '':
            value = default.get('value', '')
        out[key] = value
    return out


class Configure(Command):
    def usage(self):
        return """
usage: rock configure [--help]
       rock configure [options]
       rock configure add <profile> [options]
       rock configure update <profile> [options]
       rock configure ls
       rock configure rm <profile>
       rock configure select <profile>

Manage Rockset credential profiles. Each profile is associated
with an API key and an API endpoint.

commands:
    add, update       create a new credentials profile or update an existing one
                      Default, when no profiles exist.
    ls                list all profiles.
                      Default, when 1 or more profiles exist.
    rm                remove profile
    select            select profile to use for subsequent rock commands

arguments:
    <profile>         name of the profile you wish to create or update

options:
  -h, --help                    show this help message and exit
  -k, --api_key=API_KEY         specify API key to use for subsequent commands
  -s, --api_server=API_SERVER   specify API server URL assigned to your account
        """

    def go(self):
        creds = Credentials()

        # determine default command when none is specified
        if (
            not self.add and not self.update and not self.ls and not self.rm and
            not self.select
        ):

            # this is the `rock configure [options]` case
            # each case is explicitly called out for code readability
            # if api_key or api_server is specified in command-line,
            # then do `rock configure add default`
            if self.api_key or self.api_server:
                self.add = True
                self.profile = 'default'
            # if this is just `rock configure` and no profiles are found
            # then do `rock configure add default`
            elif len(creds.get_all_profiles()) == 0:
                self.add = True
                self.profile = 'default'
            # else just list all profiles
            else:
                self.ls = True

        # update is same as add
        if self.add or self.update:
            new_profile = self.profile
            ip = creds.get(new_profile)
            ip['api_key'] = ip.get('api_key', None)
            ip['api_server'] = ip.get(
                'api_server', 'https://api.rs2.usw2.rockset.com'
            )
            # dont prompt if command-line options are specified
            if self.api_key or self.api_server:
                ip['api_key'] = self.api_key or ip['api_key']
                ip['api_server'] = self.api_server or ip['api_server']
            else:
                ip = _interactive_prompt(
                    _prompt_api_key(ip['api_key']) +
                    _prompt_api_server(ip['api_server'])
                )
            ip['profile'] = new_profile
            profile_details = creds.set(
                profile=ip['profile'],
                api_key=ip['api_key'],
                api_server=ip['api_server']
            )
            if len(creds.get_all_profiles()) == 1:
                creds.active_profile(ip['profile'])
            creds.save()
        elif self.select:
            select_profile = self.profile
            active_profile = creds.active_profile(select_profile)
            if active_profile != select_profile:
                self.error('Could not switch to profile "%s"!' % select_profile)
            else:
                creds.save()
        elif self.rm:
            rm_profile = self.profile
            deleted_profile = creds.delete(rm_profile)
            if deleted_profile is None:
                self.error('No profile with name "%s" exists!' % rm_profile)
            else:
                creds.save()

        # print all profiles in alphabetical order
        all_profiles = creds.get_all_profiles()
        all_profile_names = list(all_profiles.keys())
        all_profile_names.sort()

        # accumulate formatted profiles
        profiles = []
        for pn in all_profile_names:
            profiles.append(
                self._format_profile(
                    pn, all_profiles[pn], creds.active_profile()
                )
            )

        self.print_list(
            0,
            profiles,
            field_order=['profile', 'api_server', 'api_key'],
            header=True
        )
        if self.format == 'text':
            self.lprint(0, 'Credentials stored in %s' % creds.creds_file)

        return 0

    def _format_profile(self, p, pd, ap):
        # prefix profile name with '*' if current
        if p == ap:
            prefix = '* '
        else:
            prefix = '  '
        pd['profile'] = prefix + p

        # don't show full api_key
        pd['api_key'] = _format_secret(pd.get('api_key', None))
        return pd



# -*- coding: utf-8 -*-
import sys

from docopt import docopt
from rockset import check_for_updates
from rockset.credentials import Credentials
from rockset.exception import AuthError


def main(args=None):
    # init args from sys
    if args is None:
        args = sys.argv[1:]

    usage = """
Command line interface to Rockset
Version: {}

Usage:
    rock [--version] [-h]
    rock help <command>
    rock [-v | -vv | -vvv] [-o=FORMAT] [-p=PROFILE] [-w] <command> [<args>...]

Commands:
    * Basic:
        create                          create a new resource
        describe                        get detailed information about a resource
        delete                          drop an existing resource
        list                            list resources of a given type
        sql                             run a SQL query from command-line or enter SQL REPL

    * Collection:
        get                             retrieve documents from a collection
        rm                              remove a document from a collection
        setstate                        sets the state of a collection to READY or PAUSED
        upload                          upload local files to a collection

    * Other:
        configure                       setup auth credentials via API keys
        help                            more information on a specific command
        play                            play a game of {{rock,paper,scissors}}

Resources:
    * collection                        a dataset, comprised of documents
    * integration                       credentials that connect Rockset to an external service
    * workspace                         organizational container for collections, can be nested like folders

Options:
    --version                           display rockset version and exit
    -h, --help                          print help message and exit
    -v, --verbose                       increase output verbosity
    -vv                                 increase output verbosity, two levels
    -vvv                                increase output verbosity, three levels
    -o, --format=FORMAT                 select output format; one of {{json,text,yaml}} [default: text]
    -p, --profile=PROFILE               select name of the credentials profile to use
    -w, --warn                          print warning messages from queries
""".format(check_for_updates())

    parsed_args = docopt(
        usage,
        argv=args,
        help=False,
        version=check_for_updates(),
        options_first=True,
    )

    if parsed_args['help']:
        return main(args=[parsed_args['<command>'], '--help'])

    alias_to_command = {
        'setup': 'configure',
        'drop': 'delete',
        'ls': 'list',
        'query': 'sql',
    }

    # setup command and args
    command = parsed_args['<command>']
    if command in alias_to_command:
        command = alias_to_command[command]
    argv = [command] + parsed_args['<args>']

    # setup credentials
    Credentials().setup()

    # process the command - delayed imports save load time for every run
    if command == 'configure':
        from rockset.rock.commands.configure import Configure
        command_cls = Configure
    elif command == 'create':
        from rockset.rock.commands.create import Create
        command_cls = Create
    elif command == 'describe':
        from rockset.rock.commands.describe import Describe
        command_cls = Describe
    elif command == 'setstate':
        from rockset.rock.commands.setstate import SetState
        command_cls = SetState
    elif command == 'delete':
        from rockset.rock.commands.drop import Drop
        command_cls = Drop
    elif command == 'list':
        from rockset.rock.commands.list import List
        command_cls = List
    elif command == 'upload':
        from rockset.rock.commands.upload import Upload
        command_cls = Upload
    elif command == 'get':
        from rockset.rock.commands.get import Get
        command_cls = Get
    elif command == 'rm':
        from rockset.rock.commands.remove import Remove
        command_cls = Remove
    elif command == 'sql':
        from rockset.rock.commands.sqlquery import SQLQuery
        command_cls = SQLQuery
    elif command == 'play':
        from rockset.rock.commands.play import Play
        command_cls = Play
    else:
        print(usage)
        return 0

    # catch exceptions in constructor
    try:
        c = command_cls(**parsed_args)
    except AuthError as e:
        print('Error: {}'.format(str(e)), file=sys.stderr)
        print(
            'Hint: Use "rock configure" to update your credentials.',
            file=sys.stderr
        )
        return 1
    except Exception as e:
        print('Error: {} {}'.format(type(e).__name__, str(e)), file=sys.stderr)
        return 1

    # let Command.main_go() deal with all exceptions here
    return c.main(argv)


if __name__ == '__main__':
    main()



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rockset.swagger_client.api_client import ApiClient


class AliasesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, workspace, body, **kwargs):  # noqa: E501
        """Create Alias  # noqa: E501

        Create new alias in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(workspace, body, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param CreateAliasRequest body: JSON object (required)
        :return: CreateAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_with_http_info(workspace, body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_with_http_info(workspace, body, **kwargs)  # noqa: E501
            return data

    def create_with_http_info(self, workspace, body, **kwargs):  # noqa: E501
        """Create Alias  # noqa: E501

        Create new alias in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_with_http_info(workspace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param CreateAliasRequest body: JSON object (required)
        :return: CreateAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `create`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases', 'POST',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateAliasResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, workspace, alias, **kwargs):  # noqa: E501
        """Delete Alias  # noqa: E501

        Delete an alias.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(workspace, alias, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :return: DeleteAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_with_http_info(workspace, alias, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_with_http_info(workspace, alias, **kwargs)  # noqa: E501
            return data

    def delete_with_http_info(self, workspace, alias, **kwargs):  # noqa: E501
        """Delete Alias  # noqa: E501

        Delete an alias.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_with_http_info(workspace, alias, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :return: DeleteAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'alias']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `delete`")  # noqa: E501
        # verify the required parameter 'alias' is set
        if ('alias' not in params or
                params['alias'] is None):
            raise ValueError("Missing the required parameter `alias` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'alias' in params:
            path_params['alias'] = params['alias']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases/{alias}', 'DELETE',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteAliasResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get(self, workspace, alias, **kwargs):  # noqa: E501
        """Get Alias  # noqa: E501

        Get details about a alias  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get(workspace, alias, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :return: GetAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_with_http_info(workspace, alias, **kwargs)  # noqa: E501
        else:
            (data) = self.get_with_http_info(workspace, alias, **kwargs)  # noqa: E501
            return data

    def get_with_http_info(self, workspace, alias, **kwargs):  # noqa: E501
        """Get Alias  # noqa: E501

        Get details about a alias  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_with_http_info(workspace, alias, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :return: GetAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'alias']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `get`")  # noqa: E501
        # verify the required parameter 'alias' is set
        if ('alias' not in params or
                params['alias'] is None):
            raise ValueError("Missing the required parameter `alias` when calling `get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'alias' in params:
            path_params['alias'] = params['alias']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases/{alias}', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAliasResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List Aliases  # noqa: E501

        Retrieve all aliases in an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List Aliases  # noqa: E501

        Retrieve all aliases in an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/aliases', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListAliasesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_0(self, workspace, alias, **kwargs):  # noqa: E501
        """Get Query Lambdas with Alias  # noqa: E501

        Get all Query Lambdas that hit a specific Rockset Alias.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_0(workspace, alias, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: (required)
        :param str alias: (required)
        :return: ListQueryLambdasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_0_with_http_info(workspace, alias, **kwargs)  # noqa: E501
        else:
            (data) = self.list_0_with_http_info(workspace, alias, **kwargs)  # noqa: E501
            return data

    def list_0_with_http_info(self, workspace, alias, **kwargs):  # noqa: E501
        """Get Query Lambdas with Alias  # noqa: E501

        Get all Query Lambdas that hit a specific Rockset Alias.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.list_0_with_http_info(workspace, alias, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: (required)
        :param str alias: (required)
        :return: ListQueryLambdasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'alias']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_0" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `list_0`")  # noqa: E501
        # verify the required parameter 'alias' is set
        if ('alias' not in params or
                params['alias'] is None):
            raise ValueError("Missing the required parameter `alias` when calling `list_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'alias' in params:
            path_params['alias'] = params['alias']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases/{alias}/lambdas', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListQueryLambdasResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, workspace, alias, body, **kwargs):  # noqa: E501
        """Update Alias  # noqa: E501

        Update alias in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(workspace, alias, body, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :param UpdateAliasRequest body: JSON object (required)
        :return: GetAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_with_http_info(workspace, alias, body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_with_http_info(workspace, alias, body, **kwargs)  # noqa: E501
            return data

    def update_with_http_info(self, workspace, alias, body, **kwargs):  # noqa: E501
        """Update Alias  # noqa: E501

        Update alias in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_with_http_info(workspace, alias, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str alias: name of the alias (required)
        :param UpdateAliasRequest body: JSON object (required)
        :return: GetAliasResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'alias', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `update`")  # noqa: E501
        # verify the required parameter 'alias' is set
        if ('alias' not in params or
                params['alias'] is None):
            raise ValueError("Missing the required parameter `alias` when calling `update`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'alias' in params:
            path_params['alias'] = params['alias']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases/{alias}', 'POST',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAliasResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace(self, workspace, **kwargs):  # noqa: E501
        """List Aliases for Workspace  # noqa: E501

        Retrieve all aliases in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace(workspace, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_with_http_info(workspace, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_with_http_info(workspace, **kwargs)  # noqa: E501
            return data

    def workspace_with_http_info(self, workspace, **kwargs):  # noqa: E501
        """List Aliases for Workspace  # noqa: E501

        Retrieve all aliases in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.workspace_with_http_info(workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/aliases', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListAliasesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CollectionStats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'doc_count': 'int',
        'purged_doc_count': 'int',
        'fill_progress': 'float',
        'last_queried_ms': 'int',
        'last_updated_ms': 'int',
        'total_size': 'int',
        'total_index_size': 'int',
        'row_index_size': 'int',
        'column_index_size': 'int',
        'inverted_index_size': 'int',
        'range_index_size': 'int',
        'purged_doc_size': 'int',
        'bytes_inserted': 'int',
        'bytes_overwritten': 'int'
    }

    attribute_map = {
        'doc_count': 'doc_count',
        'purged_doc_count': 'purged_doc_count',
        'fill_progress': 'fill_progress',
        'last_queried_ms': 'last_queried_ms',
        'last_updated_ms': 'last_updated_ms',
        'total_size': 'total_size',
        'total_index_size': 'total_index_size',
        'row_index_size': 'row_index_size',
        'column_index_size': 'column_index_size',
        'inverted_index_size': 'inverted_index_size',
        'range_index_size': 'range_index_size',
        'purged_doc_size': 'purged_doc_size',
        'bytes_inserted': 'bytes_inserted',
        'bytes_overwritten': 'bytes_overwritten'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """CollectionStats - a model defined in Swagger"""  # noqa: E501

        self._doc_count = None
        self._purged_doc_count = None
        self._fill_progress = None
        self._last_queried_ms = None
        self._last_updated_ms = None
        self._total_size = None
        self._total_index_size = None
        self._row_index_size = None
        self._column_index_size = None
        self._inverted_index_size = None
        self._range_index_size = None
        self._purged_doc_size = None
        self._bytes_inserted = None
        self._bytes_overwritten = None
        self.discriminator = None

        self.doc_count = kwargs.pop('doc_count', None)
        self.purged_doc_count = kwargs.pop('purged_doc_count', None)
        self.fill_progress = kwargs.pop('fill_progress', None)
        self.last_queried_ms = kwargs.pop('last_queried_ms', None)
        self.last_updated_ms = kwargs.pop('last_updated_ms', None)
        self.total_size = kwargs.pop('total_size', None)
        self.total_index_size = kwargs.pop('total_index_size', None)
        self.row_index_size = kwargs.pop('row_index_size', None)
        self.column_index_size = kwargs.pop('column_index_size', None)
        self.inverted_index_size = kwargs.pop('inverted_index_size', None)
        self.range_index_size = kwargs.pop('range_index_size', None)
        self.purged_doc_size = kwargs.pop('purged_doc_size', None)
        self.bytes_inserted = kwargs.pop('bytes_inserted', None)
        self.bytes_overwritten = kwargs.pop('bytes_overwritten', None)

    @property
    def doc_count(self):
        """Gets the doc_count of this CollectionStats.  # noqa: E501

        number of documents in the collection  # noqa: E501

        :return: The doc_count of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._doc_count

    @doc_count.setter
    def doc_count(self, doc_count):
        """Sets the doc_count of this CollectionStats.

        number of documents in the collection  # noqa: E501

        :param doc_count: The doc_count of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._doc_count = doc_count

    @property
    def purged_doc_count(self):
        """Gets the purged_doc_count of this CollectionStats.  # noqa: E501

        number of documents purged from the collection  # noqa: E501

        :return: The purged_doc_count of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._purged_doc_count

    @purged_doc_count.setter
    def purged_doc_count(self, purged_doc_count):
        """Sets the purged_doc_count of this CollectionStats.

        number of documents purged from the collection  # noqa: E501

        :param purged_doc_count: The purged_doc_count of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._purged_doc_count = purged_doc_count

    @property
    def fill_progress(self):
        """Gets the fill_progress of this CollectionStats.  # noqa: E501

        number between 0 and 1 that indicates progress of collection creation  # noqa: E501

        :return: The fill_progress of this CollectionStats.  # noqa: E501
        :rtype: float
        """
        return self._fill_progress

    @fill_progress.setter
    def fill_progress(self, fill_progress):
        """Sets the fill_progress of this CollectionStats.

        number between 0 and 1 that indicates progress of collection creation  # noqa: E501

        :param fill_progress: The fill_progress of this CollectionStats.  # noqa: E501
        :type: float
        """

        self._fill_progress = fill_progress

    @property
    def last_queried_ms(self):
        """Gets the last_queried_ms of this CollectionStats.  # noqa: E501

        milliseconds since Unix epoch Jan 1, 1970  # noqa: E501

        :return: The last_queried_ms of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._last_queried_ms

    @last_queried_ms.setter
    def last_queried_ms(self, last_queried_ms):
        """Sets the last_queried_ms of this CollectionStats.

        milliseconds since Unix epoch Jan 1, 1970  # noqa: E501

        :param last_queried_ms: The last_queried_ms of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._last_queried_ms = last_queried_ms

    @property
    def last_updated_ms(self):
        """Gets the last_updated_ms of this CollectionStats.  # noqa: E501

        milliseconds since Unix epoch Jan 1, 1970  # noqa: E501

        :return: The last_updated_ms of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._last_updated_ms

    @last_updated_ms.setter
    def last_updated_ms(self, last_updated_ms):
        """Sets the last_updated_ms of this CollectionStats.

        milliseconds since Unix epoch Jan 1, 1970  # noqa: E501

        :param last_updated_ms: The last_updated_ms of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._last_updated_ms = last_updated_ms

    @property
    def total_size(self):
        """Gets the total_size of this CollectionStats.  # noqa: E501

        total collection size in bytes  # noqa: E501

        :return: The total_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._total_size

    @total_size.setter
    def total_size(self, total_size):
        """Sets the total_size of this CollectionStats.

        total collection size in bytes  # noqa: E501

        :param total_size: The total_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._total_size = total_size

    @property
    def total_index_size(self):
        """Gets the total_index_size of this CollectionStats.  # noqa: E501

        total collection index size in bytes  # noqa: E501

        :return: The total_index_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._total_index_size

    @total_index_size.setter
    def total_index_size(self, total_index_size):
        """Sets the total_index_size of this CollectionStats.

        total collection index size in bytes  # noqa: E501

        :param total_index_size: The total_index_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._total_index_size = total_index_size

    @property
    def row_index_size(self):
        """Gets the row_index_size of this CollectionStats.  # noqa: E501

        total collection row index size in bytes  # noqa: E501

        :return: The row_index_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._row_index_size

    @row_index_size.setter
    def row_index_size(self, row_index_size):
        """Sets the row_index_size of this CollectionStats.

        total collection row index size in bytes  # noqa: E501

        :param row_index_size: The row_index_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._row_index_size = row_index_size

    @property
    def column_index_size(self):
        """Gets the column_index_size of this CollectionStats.  # noqa: E501

        total collection column index size in bytes  # noqa: E501

        :return: The column_index_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._column_index_size

    @column_index_size.setter
    def column_index_size(self, column_index_size):
        """Sets the column_index_size of this CollectionStats.

        total collection column index size in bytes  # noqa: E501

        :param column_index_size: The column_index_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._column_index_size = column_index_size

    @property
    def inverted_index_size(self):
        """Gets the inverted_index_size of this CollectionStats.  # noqa: E501

        total collection inverted index size in bytes  # noqa: E501

        :return: The inverted_index_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._inverted_index_size

    @inverted_index_size.setter
    def inverted_index_size(self, inverted_index_size):
        """Sets the inverted_index_size of this CollectionStats.

        total collection inverted index size in bytes  # noqa: E501

        :param inverted_index_size: The inverted_index_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._inverted_index_size = inverted_index_size

    @property
    def range_index_size(self):
        """Gets the range_index_size of this CollectionStats.  # noqa: E501

        total collection range index size in bytes  # noqa: E501

        :return: The range_index_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._range_index_size

    @range_index_size.setter
    def range_index_size(self, range_index_size):
        """Sets the range_index_size of this CollectionStats.

        total collection range index size in bytes  # noqa: E501

        :param range_index_size: The range_index_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._range_index_size = range_index_size

    @property
    def purged_doc_size(self):
        """Gets the purged_doc_size of this CollectionStats.  # noqa: E501

        total size of bytes purged in bytes  # noqa: E501

        :return: The purged_doc_size of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._purged_doc_size

    @purged_doc_size.setter
    def purged_doc_size(self, purged_doc_size):
        """Sets the purged_doc_size of this CollectionStats.

        total size of bytes purged in bytes  # noqa: E501

        :param purged_doc_size: The purged_doc_size of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._purged_doc_size = purged_doc_size

    @property
    def bytes_inserted(self):
        """Gets the bytes_inserted of this CollectionStats.  # noqa: E501

        total number of bytes inserted into the collection  # noqa: E501

        :return: The bytes_inserted of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_inserted

    @bytes_inserted.setter
    def bytes_inserted(self, bytes_inserted):
        """Sets the bytes_inserted of this CollectionStats.

        total number of bytes inserted into the collection  # noqa: E501

        :param bytes_inserted: The bytes_inserted of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._bytes_inserted = bytes_inserted

    @property
    def bytes_overwritten(self):
        """Gets the bytes_overwritten of this CollectionStats.  # noqa: E501

        total number of bytes overwritten in writing into the collection  # noqa: E501

        :return: The bytes_overwritten of this CollectionStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_overwritten

    @bytes_overwritten.setter
    def bytes_overwritten(self, bytes_overwritten):
        """Sets the bytes_overwritten of this CollectionStats.

        total number of bytes overwritten in writing into the collection  # noqa: E501

        :param bytes_overwritten: The bytes_overwritten of this CollectionStats.  # noqa: E501
        :type: int
        """

        self._bytes_overwritten = bytes_overwritten

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CollectionStats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from .command_auth import AuthCommand
from .util.parse_util import parse_collection_path
from rockset import Q, F


class Get(AuthCommand):
    def usage(self):
        return """
usage: rock get [-h] <name> <document_id>...

Fetch one or more documents as JSON from a Rockset collection.

arguments:
    <name>              name of the collection
    <document_id>       id of the documents you wish to fetch from the
                        collection

options:
    -h, --help          show this help message and exit
        """

    def go(self):
        q = Q.none
        for doc_id in self.document_id:
            q |= F["_id"] == doc_id
        workspace, name = parse_collection_path(self.name)
        resource = self.client.retrieve(name, workspace=workspace)
        self.print_list(0, resource.query(q).results())
        return 0



import requests
import rockset

from .command import Command
from rockset.exception import HTTPError, RequestTimeout, InputError


class RESTCommand(Command):
    def __init__(self, *args, **kwargs):
        super(RESTCommand, self).__init__(*args, **kwargs)
        self.require_creds()
        self.logger.info('target api_server: {}'.format(self.api_server))
        self.logger.info('target api_key: {}'.format(self.api_key_masked))

    def _url(self, url):
        return '{}{}'.format(self.api_server, url)

    def _headers(self, headers):
        if headers is None:
            headers = {}
        headers.update(
            {
                'Authorization': 'ApiKey {}'.format(self.api_key),
                'x-rockset-version': rockset.version(),
                'User-Agent': 'python',
            }
        )
        return headers

    def _exception(self, response):
        return HTTPError(code=response.status_code, message=response.reason)

    def _apicall(self, method, url, *args, **kwargs):
        return method(url, *args, **kwargs)

    def _method(self, method, url, *args, **kwargs):
        kwargs['timeout'] = kwargs.get('timeout', 10)
        kwargs['headers'] = self._headers(kwargs.get('headers'))
        try:
            response = self._apicall(method, self._url(url), *args, **kwargs)
            if response.status_code != 200:
                raise self._exception(response)
            return response.json()
        except requests.exceptions.ConnectionError as e:
            message = 'error connecting to {}'.format(self.api_server)
            raise RequestTimeout(message=message, timeout=None) from None
        except requests.exceptions.RequestException as e:
            raise InputError(
                code='-', message=str(e), type='InputError'
            ) from None

    def post(self, url, *args, **kwargs):
        return self._method(requests.post, url, *args, **kwargs)

    def get(self, url, *args, **kwargs):
        return self._method(requests.get, url, *args, **kwargs)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.query_error import QueryError  # noqa: F401,E501
from rockset.swagger_client.models.query_field_type import QueryFieldType  # noqa: F401,E501
from rockset.swagger_client.models.query_response_stats import QueryResponseStats  # noqa: F401,E501


class QueryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'collections': 'list[str]',
        'results': 'list[object]',
        'stats': 'QueryResponseStats',
        'warnings': 'list[str]',
        'query_errors': 'list[QueryError]',
        'column_fields': 'list[QueryFieldType]'
    }

    attribute_map = {
        'query_id': 'query_id',
        'collections': 'collections',
        'results': 'results',
        'stats': 'stats',
        'warnings': 'warnings',
        'query_errors': 'query_errors',
        'column_fields': 'column_fields'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """QueryResponse - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._collections = None
        self._results = None
        self._stats = None
        self._warnings = None
        self._query_errors = None
        self._column_fields = None
        self.discriminator = None

        self.query_id = kwargs.pop('query_id', None)
        self.collections = kwargs.pop('collections', None)
        self.results = kwargs.pop('results', None)
        self.stats = kwargs.pop('stats', None)
        self.warnings = kwargs.pop('warnings', None)
        self.query_errors = kwargs.pop('query_errors', None)
        self.column_fields = kwargs.pop('column_fields', None)

    @property
    def query_id(self):
        """Gets the query_id of this QueryResponse.  # noqa: E501

        unique id for this query  # noqa: E501

        :return: The query_id of this QueryResponse.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this QueryResponse.

        unique id for this query  # noqa: E501

        :param query_id: The query_id of this QueryResponse.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def collections(self):
        """Gets the collections of this QueryResponse.  # noqa: E501

        list of collections queried by the query  # noqa: E501

        :return: The collections of this QueryResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._collections

    @collections.setter
    def collections(self, collections):
        """Sets the collections of this QueryResponse.

        list of collections queried by the query  # noqa: E501

        :param collections: The collections of this QueryResponse.  # noqa: E501
        :type: list[str]
        """

        self._collections = collections

    @property
    def results(self):
        """Gets the results of this QueryResponse.  # noqa: E501

        list of objects returned by the query  # noqa: E501

        :return: The results of this QueryResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this QueryResponse.

        list of objects returned by the query  # noqa: E501

        :param results: The results of this QueryResponse.  # noqa: E501
        :type: list[object]
        """

        self._results = results

    @property
    def stats(self):
        """Gets the stats of this QueryResponse.  # noqa: E501

        meta information about the query  # noqa: E501

        :return: The stats of this QueryResponse.  # noqa: E501
        :rtype: QueryResponseStats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this QueryResponse.

        meta information about the query  # noqa: E501

        :param stats: The stats of this QueryResponse.  # noqa: E501
        :type: QueryResponseStats
        """

        self._stats = stats

    @property
    def warnings(self):
        """Gets the warnings of this QueryResponse.  # noqa: E501

        warnings received from the query  # noqa: E501

        :return: The warnings of this QueryResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this QueryResponse.

        warnings received from the query  # noqa: E501

        :param warnings: The warnings of this QueryResponse.  # noqa: E501
        :type: list[str]
        """

        self._warnings = warnings

    @property
    def query_errors(self):
        """Gets the query_errors of this QueryResponse.  # noqa: E501

        errors encountered while streaming the query  # noqa: E501

        :return: The query_errors of this QueryResponse.  # noqa: E501
        :rtype: list[QueryError]
        """
        return self._query_errors

    @query_errors.setter
    def query_errors(self, query_errors):
        """Sets the query_errors of this QueryResponse.

        errors encountered while streaming the query  # noqa: E501

        :param query_errors: The query_errors of this QueryResponse.  # noqa: E501
        :type: list[QueryError]
        """

        self._query_errors = query_errors

    @property
    def column_fields(self):
        """Gets the column_fields of this QueryResponse.  # noqa: E501

        meta information about each column in the result set  # noqa: E501

        :return: The column_fields of this QueryResponse.  # noqa: E501
        :rtype: list[QueryFieldType]
        """
        return self._column_fields

    @column_fields.setter
    def column_fields(self, column_fields):
        """Sets the column_fields of this QueryResponse.

        meta information about each column in the result set  # noqa: E501

        :param column_fields: The column_fields of this QueryResponse.  # noqa: E501
        :type: list[QueryFieldType]
        """

        self._column_fields = column_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from .command import Command
import random
import sys


# from https://stackoverflow.com/questions/510357/python-read-a-single-character-from-the-user
class _Getch:
    """Gets a single character from standard input.  Does not echo to the
screen."""
    def __init__(self):
        try:
            self.impl = _GetchWindows()
        except ImportError:
            self.impl = _GetchUnix()

    def __call__(self):
        return self.impl()


class _GetchUnix:
    def __init__(self):
        import tty, sys

    def __call__(self):
        import sys, tty, termios
        fd = sys.stdin.fileno()
        old_settings = termios.tcgetattr(fd)
        try:
            tty.setraw(sys.stdin.fileno())
            ch = sys.stdin.read(1)
        finally:
            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
        return ch


class _GetchWindows:
    def __init__(self):
        import msvcrt

    def __call__(self):
        import msvcrt
        return msvcrt.getch()


getch = _Getch()


class Play(Command):
    def usage(self):
        return """
usage: rock play

Play a game of {rock,paper,scissors}
        """

    def go(self):
        if not sys.stdin.isatty():
            self.lprint(0, 'No cheating!')
            return 0
        choices = {'r': 'rock', 'p': 'paper', 's': 'scissors'}
        wins = 0
        losses = 0
        ties = 0
        while True:
            c = random.choice(list(choices.keys()))
            self.lprint(
                0, "Enter 'r' for rock, 'p' for paper, 's' for scissors "
                "or 'q' to quit: ",
                end=" "
            ),
            sys.stdout.flush()
            u = getch()
            self.lprint(0)
            if u == 'q':
                self.lprint(0)
                break
            if u == c:
                self.lprint(0, "Tie! We both guessed '%s' " % choices[u])
                ties += 1
                continue
            if (
                (u == 'r' and c == 's') or (u == 'p' and c == 'r') or
                (u == 's' and c == 'p')
            ):
                wins += 1
                self.lprint(0, 'You win! (%s >> %s)' % (choices[u], choices[c]))
            else:
                losses += 1
                self.lprint(
                    0, 'You lose! (%s << %s)' % (choices.get(u), choices[c])
                )
        self.lprint(
            0, 'Your score summary: %d wins, %d ties and %d losses' %
            (wins, ties, losses)
        )
        return 0



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.org_membership import OrgMembership  # noqa: F401,E501
from rockset.swagger_client.models.organization import Organization  # noqa: F401,E501


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'roles': 'list[str]',
        'state': 'str',
        'org': 'str',
        'invite_state': 'str',
        'orgs': 'list[Organization]',
        'org_memberships': 'list[OrgMembership]'
    }

    attribute_map = {
        'created_at': 'created_at',
        'email': 'email',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'roles': 'roles',
        'state': 'state',
        'org': 'org',
        'invite_state': 'invite_state',
        'orgs': 'orgs',
        'org_memberships': 'org_memberships'
    }

    def __init__(self, email, **kwargs):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._roles = None
        self._state = None
        self._org = None
        self._invite_state = None
        self._orgs = None
        self._org_memberships = None
        self.discriminator = None

        self.created_at = kwargs.pop('created_at', None)
        self.email = email
        self.first_name = kwargs.pop('first_name', None)
        self.last_name = kwargs.pop('last_name', None)
        self.roles = kwargs.pop('roles', None)
        self.state = kwargs.pop('state', None)
        self.org = kwargs.pop('org', None)
        self.invite_state = kwargs.pop('invite_state', None)
        self.orgs = kwargs.pop('orgs', None)
        self.org_memberships = kwargs.pop('org_memberships', None)

    @property
    def created_at(self):
        """Gets the created_at of this User.  # noqa: E501

        ISO-8601 date  # noqa: E501

        :return: The created_at of this User.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this User.

        ISO-8601 date  # noqa: E501

        :param created_at: The created_at of this User.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501

        user email  # noqa: E501

        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.

        user email  # noqa: E501

        :param email: The email of this User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        user first name  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        user first name  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        user last name  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        user last name  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def roles(self):
        """Gets the roles of this User.  # noqa: E501

        List of roles for a given user  # noqa: E501

        :return: The roles of this User.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this User.

        List of roles for a given user  # noqa: E501

        :param roles: The roles of this User.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def state(self):
        """Gets the state of this User.  # noqa: E501

        state of user - NEW / ACTIVE  # noqa: E501

        :return: The state of this User.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this User.

        state of user - NEW / ACTIVE  # noqa: E501

        :param state: The state of this User.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def org(self):
        """Gets the org of this User.  # noqa: E501


        :return: The org of this User.  # noqa: E501
        :rtype: str
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this User.


        :param org: The org of this User.  # noqa: E501
        :type: str
        """

        self._org = org

    @property
    def invite_state(self):
        """Gets the invite_state of this User.  # noqa: E501


        :return: The invite_state of this User.  # noqa: E501
        :rtype: str
        """
        return self._invite_state

    @invite_state.setter
    def invite_state(self, invite_state):
        """Sets the invite_state of this User.


        :param invite_state: The invite_state of this User.  # noqa: E501
        :type: str
        """

        self._invite_state = invite_state

    @property
    def orgs(self):
        """Gets the orgs of this User.  # noqa: E501


        :return: The orgs of this User.  # noqa: E501
        :rtype: list[Organization]
        """
        return self._orgs

    @orgs.setter
    def orgs(self, orgs):
        """Sets the orgs of this User.


        :param orgs: The orgs of this User.  # noqa: E501
        :type: list[Organization]
        """

        self._orgs = orgs

    @property
    def org_memberships(self):
        """Gets the org_memberships of this User.  # noqa: E501


        :return: The org_memberships of this User.  # noqa: E501
        :rtype: list[OrgMembership]
        """
        return self._org_memberships

    @org_memberships.setter
    def org_memberships(self, org_memberships):
        """Sets the org_memberships of this User.


        :param org_memberships: The org_memberships of this User.  # noqa: E501
        :type: list[OrgMembership]
        """

        self._org_memberships = org_memberships

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rockset.swagger_client.api_client import ApiClient


class CollectionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, workspace, body, **kwargs):  # noqa: E501
        """Create Collection  # noqa: E501

        Create new collection in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(workspace, body, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param CreateCollectionRequest body: JSON object (required)
        :return: CreateCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_with_http_info(workspace, body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_with_http_info(workspace, body, **kwargs)  # noqa: E501
            return data

    def create_with_http_info(self, workspace, body, **kwargs):  # noqa: E501
        """Create Collection  # noqa: E501

        Create new collection in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_with_http_info(workspace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param CreateCollectionRequest body: JSON object (required)
        :return: CreateCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `create`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections', 'POST',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, workspace, collection, **kwargs):  # noqa: E501
        """Delete Collection  # noqa: E501

        Delete a collection and all its documents from Rockset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(workspace, collection, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: DeleteCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_with_http_info(workspace, collection, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_with_http_info(workspace, collection, **kwargs)  # noqa: E501
            return data

    def delete_with_http_info(self, workspace, collection, **kwargs):  # noqa: E501
        """Delete Collection  # noqa: E501

        Delete a collection and all its documents from Rockset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_with_http_info(workspace, collection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: DeleteCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'collection']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `delete`")  # noqa: E501
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections/{collection}', 'DELETE',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Collection  # noqa: E501

        Get details about a collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get(workspace, collection, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: GetCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_with_http_info(workspace, collection, **kwargs)  # noqa: E501
        else:
            (data) = self.get_with_http_info(workspace, collection, **kwargs)  # noqa: E501
            return data

    def get_with_http_info(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Collection  # noqa: E501

        Get details about a collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_with_http_info(workspace, collection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: GetCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'collection']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `get`")  # noqa: E501
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections/{collection}', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List Collections  # noqa: E501

        Retrieve all collections in an organization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListCollectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List Collections  # noqa: E501

        Retrieve all collections in an organization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListCollectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/collections', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListCollectionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_0(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Aliases for Collection  # noqa: E501

        Get all Aliases for a specific Rockset Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_0(workspace, collection, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: (required)
        :param str collection: (required)
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_0_with_http_info(workspace, collection, **kwargs)  # noqa: E501
        else:
            (data) = self.list_0_with_http_info(workspace, collection, **kwargs)  # noqa: E501
            return data

    def list_0_with_http_info(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Aliases for Collection  # noqa: E501

        Get all Aliases for a specific Rockset Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.list_0_with_http_info(workspace, collection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: (required)
        :param str collection: (required)
        :return: ListAliasesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'collection']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_0" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `list_0`")  # noqa: E501
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `list_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections/{collection}/aliases', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListAliasesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_1(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Query Lambdas for Collection  # noqa: E501

        Get all Query Lambdas that hit a specific Rockset Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_1(workspace, collection, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: ListQueryLambdaVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_1_with_http_info(workspace, collection, **kwargs)  # noqa: E501
        else:
            (data) = self.list_1_with_http_info(workspace, collection, **kwargs)  # noqa: E501
            return data

    def list_1_with_http_info(self, workspace, collection, **kwargs):  # noqa: E501
        """Get Query Lambdas for Collection  # noqa: E501

        Get all Query Lambdas that hit a specific Rockset Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.list_1_with_http_info(workspace, collection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :param str collection: name of the collection (required)
        :return: ListQueryLambdaVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'collection']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `list_1`")  # noqa: E501
        # verify the required parameter 'collection' is set
        if ('collection' not in params or
                params['collection'] is None):
            raise ValueError("Missing the required parameter `collection` when calling `list_1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501
        if 'collection' in params:
            path_params['collection'] = params['collection']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections/{collection}/lambdas', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListQueryLambdaVersionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace(self, workspace, **kwargs):  # noqa: E501
        """List Collections for Workspace  # noqa: E501

        Retrieve all collections in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace(workspace, async=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :return: ListCollectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_with_http_info(workspace, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_with_http_info(workspace, **kwargs)  # noqa: E501
            return data

    def workspace_with_http_info(self, workspace, **kwargs):  # noqa: E501
        """List Collections for Workspace  # noqa: E501

        Retrieve all collections in a workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.workspace_with_http_info(workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: name of the workspace (required)
        :return: ListCollectionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace' in params:
            path_params['workspace'] = params['workspace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = 'application/json' # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'application/json'  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/self/ws/{workspace}/collections', 'GET',
            body_params,
            path_params,
            query_params,
            header_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListCollectionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
